function yesno = iszero(A)

% ISZERO -- checks whether a numerical matrix contains only zeros
%
%        yesno = iszero(A)
%
% If the numerical matrix A contains only entries which are zero
% (within tolerance), this routine returns yesno=1, otherwise yesno=0.
%
% The tolerance is the value of the global variable MPOLY_TOLERANCE.
% If this variable is not set, it defaults to 1.e-12.

% Copyright (c) 2004 by Fritz Keinert (keinert@iastate.edu),
% Dept. of Mathematics, Iowa State University, Ames, IA 50011.
% This software may be freely used and distributed for non-commercial
% purposes, provided this copyright statement is preserved, and
% appropriate credit for its use is given.
%
% Last update: Feb 20, 2004

global MPOLY_TOLERANCE

if ~isempty(MPOLY_TOLERANCE)
    tol = MPOLY_TOLERANCE;
else
    tol = 1.e-12;
end

yesno = (max(abs(A(:))) < tol);
