function P = round(P)

% ROUND -- built-in ROUND, extended to matrix polynomials
%
%        P = round(P)
%
% Round entries in P.coef to the nearest integer.

% Copyright (c) 2004 by Fritz Keinert (keinert@iastate.edu),
% Dept. of Mathematics, Iowa State University, Ames, IA 50011.
% This software may be freely used and distributed for non-commercial
% purposes, provided this copyright statement is preserved, and
% appropriate credit for its use is given.
%
% Last update: Feb 20, 2004

if isnumeric(P)
    P.coef = round(P.coef);
elseif ~issymbolic(P)
% P contains only symbolic constants, not symbolic variables
% We convert to numbers, round, and convert back to symbolic form
% The "reshape" is necessary since Matlab cannot handle
% three-dimensional symbolic arrays correctly
    P.coef = reshape(sym(round(double(P.coef(:)))),size(P.coef));
else
    error('ROUND is not defined for symbolic variables');
end
P = trim(P);
