function Pt = transpose(P)

% TRANSPOSE -- real transpose of matrix polynomial
%
%        Pt = transpose(P)
%        Pt = P.'
%
% This routine is not meant to be called by the user. It is called by
% Matlab when the expression P.' is encountered. It takes the real
% transpose of all the coefficient matrices.

% Copyright (c) 2004 by Fritz Keinert (keinert@iastate.edu),
% Dept. of Mathematics, Iowa State University, Ames, IA 50011.
% This software may be freely used and distributed for non-commercial
% purposes, provided this copyright statement is preserved, and
% appropriate credit for its use is given.
%
% Last update: Feb 20, 2004

Pt = P;
[n1,n2,n3] = size(P.coef);
% the next line just creates space for Pt of the correct size and data type
Pt.coef = reshape(Pt.coef,n2,n1,n3);
for i = 1:n3
    Pt.coef(:,:,i) = P.coef(:,:,i).';
end
