function M = discrete_moment(H,k)

% DISCRETE_MOMENT - compute multiwavelet discrete moments
%
%        M = discrete_moment(H,k)
%
% The kth moment of H is defined as
%              _
%             \    k
%        M  = /_  j  H . 
%         k    j      j      
%
% k must be a vector of non-negative integers. Default is k=0.
%
% H can be a symbol or a polyphase matrix. The result will be a 
% three-dimensional matrix with the first two dimensions the same
% size as H. The third dimension corresponds
% to the different values of K.

% Copyright (c) 2004 by Fritz Keinert (keinert@iastate.edu),
% Dept. of Mathematics, Iowa State University, Ames, IA 50011.
% This software may be freely used and distributed for non-commercial
% purposes, provided this copyright statement is preserved, and
% appropriate credit for its use is given.
%
% Last update: Feb 20, 2004

if (nargin < 2)
    k = 0;
end

% convert H into a symbol, if necessary
H = symbol(H);

% compute the moment(s)
[n1,n2] = size(H);
M = zeros(n1,n2,length(k));
if (isa(H.coef,'sym'))
    M = sym(M);
end
for i = 1:length(k)
    M(:,:,i) = moment(H,k(i));
end
